
/*
RC Light Switch Controller

The code for the controller of
the remote control light switch.

Alan Merritt
12/13/2021
*/

//Import the RF module library.
#include <SPI.h>
#include <RF24.h>

//Declare our RF24 radio. Pin number 40 on the Arduino mega
//connects to the CE pin on the module and pin 38 connects
//to its CSN pin.
RF24 radio(40, 38);

//This is the address with which the two modules will use to communicate.
//Make sure that the address that the switch uses is the same.
const byte address[6] = "00001";

//This value stores if the button was pressed in the previous time through the loop.
bool lastRead = false;

const int buttonPin = 7;

void setup() {

  Serial.begin(9600);
  
  //Set the button pin to an input mode. The button is
  //connected to the ground pin and a digital pin. The
  //INPUT_PULLUP mode makes it so that we don't need a resistor.
  pinMode(buttonPin, INPUT_PULLUP);

  //Set up the radio in write mode.
  radio.begin();

  radio.setPALevel(RF24_PA_LOW);

  //Set the address.
  radio.openWritingPipe(address);

  //Stop listening - set to transmit.
  radio.stopListening();

  Serial.println("Started.");

}

void loop() {
  
  //Read the value of the button pin.
  bool thisRead = digitalRead(buttonPin);

  //If the button was pressed this time, but not last time through
  //the loop, we will send that the button has been pressed.
  bool isPressed = thisRead && !lastRead;

  if(isPressed)
  {
    //Send that the button was pressed to the other module.
    radio.write(&isPressed, sizeof(isPressed));
    Serial.println("Sent");
  }

  //Update the lastRead variable so that in the next loop, it
  //will have the value thisRead had during this loop.
  lastRead = thisRead;

  delay(5);

}
